@@ -73,12 +73,20 @@ class AioTransport(xmlrpc.Transport):
             if response.status != 200:
                 raise ProtocolError(url, response.status,
                                     body, response.headers)
+        except asyncio.CancelledError:
+            raise
         except ProtocolError:
             raise
         except Exception as exc:
             log.error('Unexpected error', exc_info=True)
-            raise ProtocolError(url, response.status,
-                                str(exc), response.headers)
+            if response is not None:
+                errcode = response.status
+                headers = response.headers
+            else:
+                errcode = 0
+                headers = {}
+
+            raise ProtocolError(url, errcode, str(exc), headers)
         return self.parse_response(body)
 
     def parse_response(self, body):
